@@ -1,4 +1,4 @@
-use super::ArwenBigUint;
+use super::{ArwenBigInt, ArwenBigUint};
 use crate::ArwenApiImpl;
 use alloc::vec::Vec;
 use elrond_wasm::api::{BlockchainApi, SendApi, StorageReadApi, StorageWriteApi};
@@ -107,7 +107,16 @@ extern "C" {
 	fn getReturnData(result_index: i32, dataOffset: *const u8) -> i32;
 }
 
-impl SendApi<ArwenBigUint> for ArwenApiImpl {
+impl SendApi for ArwenApiImpl {
+	type AmountType = ArwenBigUint;
+	type ProxyBigInt = ArwenBigInt;
+	type ProxyStorage = Self;
+
+	#[inline]
+	fn get_sc_address(&self) -> Address {
+		BlockchainApi::get_sc_address(self)
+	}
+
 	fn direct_egld(&self, to: &Address, amount: &ArwenBigUint, data: &[u8]) {
 		unsafe {
 			let amount_bytes32_ptr = amount.unsafe_buffer_load_be_pad_right(32);
@@ -377,7 +386,7 @@ impl SendApi<ArwenBigUint> for ArwenApiImpl {
 
 	fn call_local_esdt_built_in_function(&self, gas: u64, function: &[u8], arg_buffer: &ArgBuffer) {
 		// account-level built-in function, so the destination address is the contract itself
-		let own_address = self.get_sc_address();
+		let own_address = BlockchainApi::get_sc_address(self);
 
 		let _ = self.execute_on_dest_context_raw(
 			gas,
